@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:51:08
-# @Last Modified time: 2021-04-19 19:53:05
+# @Last Modified time: 2021-04-28 13:32:20
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -130,9 +130,9 @@ class SqlFileParse(object):
         argsamelog = None
         if arguments_same:
             arguments_same = sorted(arguments_same)
-            input_arg = {arg: kwargs.get(arg) for arg in arguments_same}
+            # input_arg = {arg: kwargs.get(arg) for arg in arguments_same}
             file_arg = {arg: arguments.get(arg) for arg in arguments_same}
-            argsamelog = f"Input {input_arg} replace filesetting {file_arg}"
+            argsamelog = f"Replace FileSetting {file_arg}"
             # sqllogger.warning(f"File 【{filename}】 {arguments_same} Use Input arguments {input_arg}, NotUse sqlfile setting {file_arg}!")
 
         arguments.update(kwargs)
@@ -145,7 +145,8 @@ class SqlFileParse(object):
             content = re.sub(rf"\${key}{self.reg_behind}", f"{value}", content)
         arguments = {k: arguments.get(k) for k in self.parameters}
 
-        arglog = f"【Final Arguments】【{filename}】 Use arguments {arguments}"
+        arglog = f"【Final Arguments】【{filename}】 Use arguments {arguments}" \
+                 if arguments else f"【Final Arguments】【{filename}】 no arguments !!!"
         arglog = arglog + f", {argsamelog}" if argsamelog else arglog
         sqllogger.warning(arglog)
 
